CHANGELOG.md
============


v0.1.0 (2017-06-24)
-------------------

 - Make uber behavior be toggleable and off by default
 - Select reviewers based on the files that were changed


v0.0.2 (2017-06-20)
-------------------

 - Add initial support for finding repository committers as a list of reviewers
